# Debian-to-SPDX

[![Apache2.0 License](https://img.shields.io/badge/License-Apatch2.0-green.svg?style=for-the-badge)](https://choosealicense.com/licenses/apache-2.0/)

vscode, Github, poetryを使ったpythonの環境設定とパッケージ作成のテンプレート

書き方の参考にするために適当な関数を残してあるが設定ファイルをクリーンにしているため、そのままでは動かない。
動かすにはjoblibを入れる必要がある。

また、python-templateやtemplateは作成するリポジトリやパッケージの名前に合わせて変更すること

## Usage/Examples

```bash
teplate 1 3 5 -c 22 --both
```


## Running Tests

To run tests, run the following command

```bash
pytest -q tests
```


## Authors

- [@tk-tanab](https://github.com/tk-tanab)


## License

- [Apatch2.0](https://choosealicense.com/licenses/apache-2.0/)

